@@ -8,12 +8,12 @@ this interface to provide their own caching mechanism.
 from dataclasses import dataclass, field
 from typing import Any, Protocol
 
-from roborock.data import CombinedMapInfo, HomeData, NetworkInfo
+from roborock.data import CombinedMapInfo, HomeData, NetworkInfo, RoborockBase
 from roborock.device_features import DeviceFeatures
 
 
 @dataclass
-class CacheData:
+class CacheData(RoborockBase):
     """Data structure for caching device information."""
 
     home_data: HomeData | None = None
@@ -22,8 +22,17 @@ class CacheData:
     network_info: dict[str, NetworkInfo] = field(default_factory=dict)
     """Network information indexed by device DUID."""
 
-    home_cache: dict[int, CombinedMapInfo] = field(default_factory=dict)
-    """Home cache information indexed by map_flag."""
+    home_map_info: dict[int, CombinedMapInfo] = field(default_factory=dict)
+    """Home map information indexed by map_flag."""
+
+    home_map_content: dict[int, bytes] = field(default_factory=dict)
+    """Home cache content for each map data indexed by map_flag.
+
+    This is deprecated in favor of `home_map_content_base64`.
+    """
+
+    home_map_content_base64: dict[int, str] = field(default_factory=dict)
+    """Home cache content for each map data (encoded base64) indexed by map_flag."""
 
     device_features: DeviceFeatures | None = None
     """Device features information."""
